@@ -4,9 +4,6 @@ from os.path import join, dirname, splitext
 from typing import Dict, Any
 from coreml.utils.io import read_yml, save_yml
 
-# project home mounted inside docker
-HOME = "/workspace/coreml/"
-
 # user-dependent output directory mounted inside docker
 OUT_DIR = "/output/"
 
@@ -24,7 +21,7 @@ class Config:
     def __init__(self, version: str):
         assert version.endswith('.yml')
         self.version = version
-        self.paths = {'HOME': HOME, 'OUT_DIR': OUT_DIR}
+        self.paths = {'OUT_DIR': OUT_DIR}
 
         config_path = os.path.join(self.paths['HOME'], version)
         config_subpath = version.replace('.yml', '')
