@@ -118,17 +118,16 @@ class BinaryClassificationModel(Model):
         return losses
 
     def _gather_data(self, epoch_data: dict) -> Tuple:
-        """Gather inputs, preds, targets & other epoch data in one tensor
+        """Gather preds, targets & other epoch data in one tensor
 
         :param epoch_data: dictionary containing lists of various epoch values
         :type epoch_data: dict
 
         :return: dictionary with different values as one tensor
         """
-        epoch_data['inputs'] = torch.cat(epoch_data['inputs']).cpu().numpy()
         epoch_data['predictions'] = torch.cat(
-            epoch_data['predictions']).detach().cpu()
-        epoch_data['targets'] = torch.cat(epoch_data['targets']).detach().cpu()
+            epoch_data['predictions'])
+        epoch_data['targets'] = torch.cat(epoch_data['targets'])
         epoch_data['items'] = np.hstack(epoch_data['items'])
         return epoch_data
 
@@ -314,7 +313,7 @@ class BinaryClassificationModel(Model):
         :param recall: minimum recall to choose the optimal threshold
         :type recall: float, defaults to 0.9
         :param as_logits: whether the predictions are logits; if
-            as_logits=True, the values are converted into softmax scores
+            as_logits=True, the values are converted into sigmoid scores
             before further processing.
         :type as_logits: bool, defaults to True
         :param classes: list of classes in the target
@@ -323,7 +322,7 @@ class BinaryClassificationModel(Model):
         :return: dictionary of metrics as provided in the config file
         """
         if as_logits:
-            # convert to softmax scores from logits
+            # convert to sigmoid scores from logits
             predictions = torch.sigmoid(predictions)
 
         targets = targets.cpu()
@@ -376,7 +375,7 @@ class BinaryClassificationModel(Model):
         plt.close()
 
         if len(torch.unique(targets)) == 1:
-            metrics['auc-roc'] = '-'
+            metrics['auc-roc'] = 0
         else:
             metrics['auc-roc'] = roc_auc_score(targets, predict_proba)
 
@@ -410,7 +409,7 @@ class BinaryClassificationModel(Model):
                 'network': self.network.get_state_dict(),
                 'optimizer': self.optimizer.state_dict(),
                 'epoch': self.epoch_counter,
-                'metrics': epoch_metric_values
+                # 'metrics': epoch_metric_values
             }, save_status['path'])
 
     def load(self, load_config: Dict):
@@ -504,9 +503,6 @@ class BinaryClassificationModel(Model):
         super(BinaryClassificationModel, self)._update_wandb(
             mode, epoch_losses, metrics)
 
-        # decide indices to visualize
-        indices = get_indices(epoch_data['targets'])
-
         # log learning rates vs losses
         if learning_rates is not None and batch_losses is not None:
             lr_vs_loss = plot_lr_vs_loss(
@@ -514,13 +510,6 @@ class BinaryClassificationModel(Model):
             self.wandb_logs['{}/lr-vs-loss'.format(mode)] = lr_vs_loss
             plt.close()
 
-        # log original inputs
-        input_images = get_images(
-            epoch_data['inputs'][indices].tolist(),
-            epoch_data['predictions'][indices],
-            epoch_data['targets'][indices])
-        self.wandb_logs['{}/inputs'.format(mode)] = input_images
-
         self.wandb_logs['{}/confusion_matrix'.format(mode)] = wandb.Image(
             get_confusion_matrix(
                 metrics['confusion_matrix'], self.model_config['classes']))
@@ -534,30 +523,39 @@ class BinaryClassificationModel(Model):
 
     def evaluate(
             self, data_loader: DataLoader, mode: str, use_wandb: bool = True,
-            ignore_cache: bool = True, threshold: float = None,
-            recall: float = 0.9, data_only: bool = False,
-            save: bool = True, log_summary: bool = True):
+            ignore_cache: bool = True, data_only: bool = False,
+            log_summary: bool = True):
         """Evaluate the model on given data
 
         :param data_loader: data_loader made from the evaluation dataset
         :type data_loader: DataLoader
-        :param mode: split of the data represented by the dataloader (train/test/val)
+        :param mode: split of the data represented by the dataloader
+            (train/test/val)
         :type mode: str
         :param use_wandb: flag to decide whether to log visualizations to wandb
         :type use_wandb: bool, defaults to True
         :param ignore_cache: whether to ignore cached values
         :type ignore_cache: bool, defaults to True
-        :param threshold: confidence threshold to be used for binary
-            classification; if None, the optimal threshold is found.
-        :type threshold: float, defaults to None
-        :param recall: minimum recall to choose the optimal threshold
-        :type recall: float, defaults to 0.9
         :param data_only: whether to only return the epoch data without
             computing metrics
         :type data_only: bool, defaults to False
-        :param save: whether to save eval data
-        :type save: bool, defaults to True
         :param log_summary: whether to log epoch summary
         :type log_summary: bool, defaults to True
         """
-        pass
+        ckpt_name = basename(self.load_path).split('.')[0]
+        cache_path = join(
+            self.config.output_dir, 'evaluation', ckpt_name, 'cache',
+            '{}.pt'.format(mode))
+        makedirs(dirname(cache_path), exist_ok=True)
+
+        # prevent logging anything into wandb when processing epoch
+        results = self.process_epoch(
+            data_loader, mode=mode, training=False, use_wandb=False,
+            log_summary=log_summary)
+
+        if data_only:
+            return results
+
+        # update wandb
+        if use_wandb:
+            self._update_wandb(mode, {}, results, results)
